@@ -2075,7 +2075,7 @@ static int  jmacroexec(const char *str, BtjobRef jp)
 		}
 		else
 			argbuf[1] = (char *) 0;
-		chdir(Curr_pwd);
+		Ignored_error = chdir(Curr_pwd);
 		execv(execprog, argbuf);
 		exit(E_BTEXEC1);
 	}
